@@ -22,4 +22,6 @@ type Config struct {
 	Guide                 bool
 	DBPath                string
 	ShowContext           bool
+	ConfirmBeforeDeletion bool
+	CircularNav           bool
 }
