@@ -61,17 +61,17 @@ type tasksFetched struct {
 type textEditorClosed struct {
 	fPath      string
 	taskIndex  int
-	taskId     uint64
+	taskID     uint64
 	oldContext *string
 	err        error
 }
 
-type urlOpenedMsg struct {
+type uriOpenedMsg struct {
 	url string
 	err error
 }
 
-type urlsOpenedDarwinMsg struct {
+type urisOpenedDarwinMsg struct {
 	urls []string
 	err  error
 }
