@@ -1,9 +1,10 @@
 package ui
 
 import (
+	_ "embed"
 	"fmt"
 	"os"
-	"strconv"
+	"sort"
 	"strings"
 	"time"
 
@@ -17,17 +18,40 @@ import (
 )
 
 const (
-	noSpaceAvailableMsg   = "Task list is at capacity. Archive/delete tasks using ctrl+d/ctrl+x."
-	noContextMsg          = "∅"
-	viewPortMoveLineCount = 3
+	noSpaceAvailableMsg         = "Task list is at capacity. Archive/delete tasks using ctrl+d/ctrl+x."
+	noContextMsg                = "  ∅"
+	viewPortMoveLineCount       = 3
+	cannotMoveWhenFilteredMsg   = "Can't move items when the task list is filtered"
+	cannotAddWhenFilteredMsg    = "Can't add items when the task list is filtered"
+	cannotDeleteWhenFilteredMsg = "Can't delete items when the task list is filtered"
+	somethingWentWrongMsg       = "Something went wrong"
 )
 
-func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
+//go:embed assets/help.md
+var helpStr string
+
+func (m Model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 	var cmd tea.Cmd
 	var cmds []tea.Cmd
 	m.successMsg = ""
 	m.errorMsg = ""
 
+	if m.activeView == taskListView || m.activeView == archivedTaskListView {
+		switch msg := msg.(type) {
+		case tea.KeyMsg:
+			if m.taskList.FilterState() == list.Filtering {
+				m.taskList, cmd = m.taskList.Update(msg)
+				cmds = append(cmds, cmd)
+				return m, tea.Batch(cmds...)
+			}
+			if m.archivedTaskList.FilterState() == list.Filtering {
+				m.archivedTaskList, cmd = m.archivedTaskList.Update(msg)
+				cmds = append(cmds, cmd)
+				return m, tea.Batch(cmds...)
+			}
+		}
+	}
+
 	if m.activeView == taskEntryView {
 		switch msg := msg.(type) {
 		case tea.KeyMsg:
@@ -45,6 +69,14 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 					break
 				}
 
+				summEls := strings.Split(taskSummary, types.PrefixDelimiter)
+				if len(summEls) > 1 {
+					if summEls[0] == "" {
+						m.errorMsg = "prefix cannot be empty"
+						break
+					}
+				}
+
 				switch m.taskChange {
 				case taskInsert:
 					now := time.Now()
@@ -54,12 +86,79 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 					m.activeView = taskListView
 					m.activeTaskList = activeTasks
 				case taskUpdateSummary:
-					cmd = updateTaskSummary(m.db, m.taskIndex, m.taskId, taskSummary)
+					cmd = updateTaskSummary(m.db, m.taskIndex, m.taskID, taskSummary)
 					cmds = append(cmds, cmd)
 					m.taskInput.Reset()
 					m.activeView = taskListView
 					m.activeTaskList = activeTasks
 				}
+
+			case "ctrl+p":
+				if len(m.taskList.Items()) == 0 {
+					m.errorMsg = "No items in task list"
+					break
+				}
+
+				tasksPrefixes := make(map[types.TaskPrefix]struct{})
+
+				summary := m.taskInput.Value()
+
+				currentPrefix, prefixPresent := getPrefix(summary)
+
+				for _, li := range m.taskList.Items() {
+					t, ok := li.(types.Task)
+					if !ok {
+						continue
+					}
+
+					prefix, pOk := t.Prefix()
+					if !pOk {
+						continue
+					}
+
+					if prefixPresent && prefix.FilterValue() == currentPrefix {
+						continue
+					}
+
+					tasksPrefixes[prefix] = struct{}{}
+				}
+
+				var prefixes []types.TaskPrefix
+				for k := range tasksPrefixes {
+					prefixes = append(prefixes, k)
+				}
+
+				if len(prefixes) == 0 {
+					m.errorMsg = "No prefixes in task list"
+					break
+				}
+
+				if len(prefixes) == 1 {
+					m.errorMsg = "Only 1 unique prefix in task list"
+					break
+				}
+
+				sort.Slice(prefixes, func(i, j int) bool {
+					return prefixes[i] < prefixes[j]
+				})
+
+				pi := make([]list.Item, len(prefixes))
+				for i, p := range prefixes {
+					pi[i] = list.Item(p)
+				}
+
+				m.prefixSearchList.SetItems(pi)
+				m.lastActiveView = m.activeView
+				m.activeView = prefixSelectionView
+				switch prefixPresent {
+				case true:
+					m.prefixSearchList.Title = "change prefix"
+				case false:
+					m.prefixSearchList.Title = "choose prefix"
+				}
+				m.prefixSearchUse = prefixChoose
+
+				return m, tea.Batch(cmds...)
 			}
 		}
 
@@ -68,36 +167,34 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 		return m, tea.Batch(cmds...)
 	}
 
+	skipListUpdate := false
+
 	switch msg := msg.(type) {
 	case tea.WindowSizeMsg:
 		w, h := listStyle.GetFrameSize()
-		_, h2 := headerStyle.GetFrameSize()
 		_, h3 := statusBarMsgStyle.GetFrameSize()
 		m.terminalWidth = msg.Width
 		m.terminalHeight = msg.Height
 		m.taskList.SetWidth(msg.Width - w)
 		m.archivedTaskList.SetWidth(msg.Width - 2)
-		m.contextBMList.SetWidth(msg.Width - 2)
-		m.contextBMList.SetHeight(msg.Height - h - 4)
+		m.taskBMList.SetWidth(msg.Width - 2)
+		m.taskBMList.SetHeight(msg.Height - h - h3 - 1)
+		m.prefixSearchList.SetWidth(msg.Width - 2)
+		m.prefixSearchList.SetHeight(msg.Height - h - h3 - 1)
 
 		var listHeight int
+		contextHeight := (msg.Height - h - h3 - 5) / 2
+
+		m.shortenedListHt = msg.Height - contextHeight - 5
+
 		if m.cfg.ShowContext {
-			listHeight = msg.Height/2 - h
+			listHeight = m.shortenedListHt
 		} else {
-			listHeight = msg.Height - h - 4
+			listHeight = msg.Height - h - h3 - 1
 		}
 
-		if m.cfg.ListDensity == Spacious {
-			m.taskList.SetHeight(listHeight)
-			m.archivedTaskList.SetHeight(listHeight)
-		}
-
-		var contextHeight int
-		if m.cfg.ListDensity == Compact {
-			contextHeight = m.terminalHeight - m.taskList.Height() - h2 - h3 - 6
-		} else {
-			contextHeight = m.terminalHeight - m.taskList.Height() - h2 - h3 - 5
-		}
+		m.taskList.SetHeight(listHeight)
+		m.archivedTaskList.SetHeight(listHeight)
 
 		if !m.contextVPReady {
 			m.contextVP = viewport.New(msg.Width-3, contextHeight)
@@ -118,9 +215,27 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 			m.taskDetailsVP.Height = m.terminalHeight - 4
 		}
 
+		crWrap := (msg.Width - 4)
+		if crWrap > contextWordWrapUpperLimit {
+			crWrap = contextWordWrapUpperLimit
+		}
+		m.contextMdRenderer, _ = utils.GetMarkDownRenderer(crWrap)
+
+		helpToRender := helpStr
+		switch m.contextMdRenderer {
+		case nil:
+			break
+		default:
+			helpStrGl, err := m.contextMdRenderer.Render(helpStr)
+			if err != nil {
+				break
+			}
+			helpToRender = helpStrGl
+		}
+
 		if !m.helpVPReady {
 			m.helpVP = viewport.New(msg.Width-3, m.terminalHeight-4)
-			m.helpVP.SetContent(helpStr)
+			m.helpVP.SetContent(helpToRender)
 			m.helpVP.KeyMap.Up.SetEnabled(false)
 			m.helpVP.KeyMap.Down.SetEnabled(false)
 			m.helpVPReady = true
@@ -130,6 +245,20 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 		}
 
 	case tea.KeyMsg:
+		if m.cfg.ConfirmBeforeDeletion && m.showDeletePrompt && msg.String() != "ctrl+x" {
+			m.showDeletePrompt = false
+
+			switch m.activeView {
+			case taskListView:
+				m.taskList.Title = m.cfg.TaskListTitle
+				m.taskList.Styles.Title = m.taskList.Styles.Title.Background(lipgloss.Color(m.cfg.TaskListColor))
+			case archivedTaskListView:
+				m.archivedTaskList.Title = archivedTitle
+				m.archivedTaskList.Styles.Title = m.archivedTaskList.Styles.Title.Background(lipgloss.Color(m.cfg.ArchivedTaskListColor))
+			}
+			return m, tea.Batch(cmds...)
+		}
+
 		switch keypress := msg.String(); keypress {
 
 		case "Q":
@@ -142,6 +271,16 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 		case "esc", "q", "ctrl+c":
 			av := m.activeView
 
+			if m.activeView == taskListView && m.taskList.IsFiltered() {
+				m.taskList.ResetFilter()
+				break
+			}
+
+			if m.activeView == archivedTaskListView && m.archivedTaskList.IsFiltered() {
+				m.archivedTaskList.ResetFilter()
+				break
+			}
+
 			if m.activeView == archivedTaskListView {
 				m.activeView = taskListView
 				m.activeTaskList = activeTasks
@@ -160,6 +299,14 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 				break
 			}
 
+			if m.activeView == prefixSelectionView {
+				m.activeView = m.lastActiveView
+				if m.prefixSearchUse == prefixChoose {
+					return m, tea.Batch(cmds...)
+				}
+				break
+			}
+
 			m.quitting = true
 			if m.cfg.Guide {
 				_ = os.Remove(m.cfg.DBPath)
@@ -167,7 +314,7 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 			return m, tea.Quit
 
 		case "?":
-			if m.activeView == taskDetailsView {
+			if m.activeView == taskDetailsView || m.activeView == contextBookmarksView || m.activeView == prefixSelectionView {
 				break
 			}
 
@@ -179,51 +326,17 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 			m.activeView = helpView
 
 		case "tab", "shift+tab":
-			m.lastActiveView = m.activeView
 			switch m.activeView {
 			case taskListView:
 				m.activeView = archivedTaskListView
 				m.activeTaskList = archivedTasks
+				m.lastActiveView = m.activeView
 			case archivedTaskListView:
 				m.activeView = taskListView
 				m.activeTaskList = activeTasks
+				m.lastActiveView = m.activeView
 			}
 
-		case "2", "3", "4", "5", "6", "7", "8", "9":
-			if m.cfg.ListDensity != Compact {
-				break
-			}
-
-			if m.activeView != taskListView {
-				break
-			}
-
-			keyNum, err := strconv.Atoi(keypress)
-			if err != nil {
-				m.errorMsg = "Something went horribly wrong"
-				break
-			}
-
-			if m.taskList.Index() == 0 && keyNum == 1 {
-				break
-			}
-
-			index := (m.taskList.Paginator.Page * m.taskList.Paginator.PerPage) + (keyNum - 1)
-
-			if index >= len(m.taskList.Items()) {
-				m.errorMsg = "There is no item for this index"
-				break
-			}
-			listItem := m.taskList.Items()[index]
-
-			m.taskList.RemoveItem(index)
-			cmd = m.taskList.InsertItem(0, listItem)
-			cmds = append(cmds, cmd)
-			m.taskList.Select(0)
-
-			cmd = m.updateTaskSequence()
-			cmds = append(cmds, cmd)
-
 		case "I":
 			if m.activeView != taskListView {
 				break
@@ -234,6 +347,11 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 				break
 			}
 
+			if m.taskList.IsFiltered() {
+				m.errorMsg = cannotAddWhenFilteredMsg
+				break
+			}
+
 			m.taskIndex = 0
 			m.taskInput.Reset()
 			m.taskInput.Focus()
@@ -251,6 +369,11 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 				break
 			}
 
+			if m.taskList.IsFiltered() {
+				m.errorMsg = cannotAddWhenFilteredMsg
+				break
+			}
+
 			m.taskIndex = m.taskList.Index()
 			m.taskInput.Reset()
 			m.taskInput.Focus()
@@ -268,6 +391,11 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 				break
 			}
 
+			if m.taskList.IsFiltered() {
+				m.errorMsg = cannotAddWhenFilteredMsg
+				break
+			}
+
 			if len(m.taskList.Items()) == 0 {
 				m.taskIndex = 0
 			} else {
@@ -289,6 +417,11 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 				break
 			}
 
+			if m.taskList.IsFiltered() {
+				m.errorMsg = cannotAddWhenFilteredMsg
+				break
+			}
+
 			m.taskIndex = len(m.taskList.Items())
 			m.taskInput.Reset()
 			m.taskInput.Focus()
@@ -296,17 +429,48 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 			m.activeView = taskEntryView
 			return m, tea.Batch(cmds...)
 
-		case "j":
-			if m.activeView != taskDetailsView && m.activeView != helpView {
-				break
-			}
-
+		case "down", "j":
 			switch m.activeView {
+			case taskListView, archivedTaskListView, contextBookmarksView, prefixSelectionView:
+				if !m.cfg.CircularNav {
+					break
+				}
+
+				// cycle back to top
+				var list *list.Model
+				switch m.activeView {
+				case taskListView:
+					list = &m.taskList
+				case archivedTaskListView:
+					list = &m.archivedTaskList
+				case contextBookmarksView:
+					list = &m.taskBMList
+				case prefixSelectionView:
+					list = &m.prefixSearchList
+				default:
+					break
+				}
+
+				if list.IsFiltered() {
+					break
+				}
+
+				numItems := len(list.Items())
+				if numItems <= 1 {
+					break
+				}
+
+				if list.Index() == numItems-1 {
+					list.Select(0)
+					skipListUpdate = true
+				}
+
 			case taskDetailsView:
 				if m.taskDetailsVP.AtBottom() {
 					break
 				}
 				m.taskDetailsVP.LineDown(viewPortMoveLineCount)
+
 			case helpView:
 				if m.helpVP.AtBottom() {
 					break
@@ -314,17 +478,48 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 				m.helpVP.LineDown(viewPortMoveLineCount)
 			}
 
-		case "k":
-			if m.activeView != taskDetailsView && m.activeView != helpView {
-				break
-			}
-
+		case "up", "k":
 			switch m.activeView {
+			case taskListView, archivedTaskListView, contextBookmarksView, prefixSelectionView:
+				if !m.cfg.CircularNav {
+					break
+				}
+
+				// cycle to the end
+				var list *list.Model
+				switch m.activeView {
+				case taskListView:
+					list = &m.taskList
+				case archivedTaskListView:
+					list = &m.archivedTaskList
+				case contextBookmarksView:
+					list = &m.taskBMList
+				case prefixSelectionView:
+					list = &m.prefixSearchList
+				default:
+					break
+				}
+
+				if list.IsFiltered() {
+					break
+				}
+
+				numItems := len(list.Items())
+				if numItems <= 1 {
+					break
+				}
+
+				if list.Index() == 0 {
+					list.Select(numItems - 1)
+					skipListUpdate = true
+				}
+
 			case taskDetailsView:
 				if m.taskDetailsVP.AtTop() {
 					break
 				}
 				m.taskDetailsVP.LineUp(viewPortMoveLineCount)
+
 			case helpView:
 				if m.helpVP.AtTop() {
 					break
@@ -338,6 +533,7 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 			}
 
 			if m.taskList.IsFiltered() {
+				m.errorMsg = cannotMoveWhenFilteredMsg
 				break
 			}
 
@@ -356,7 +552,7 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 			m.taskList.SetItem(ci+1, currentItem)
 			m.taskList.Select(ci + 1)
 
-			cmd = m.updateTaskSequence()
+			cmd = m.updateActiveTasksSequence()
 			cmds = append(cmds, cmd)
 
 		case "K":
@@ -365,6 +561,7 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 			}
 
 			if m.taskList.IsFiltered() {
+				m.errorMsg = cannotMoveWhenFilteredMsg
 				break
 			}
 
@@ -379,7 +576,7 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 			m.taskList.SetItem(ci-1, currentItem)
 			m.taskList.Select(ci - 1)
 
-			cmd = m.updateTaskSequence()
+			cmd = m.updateActiveTasksSequence()
 			cmds = append(cmds, cmd)
 
 		case "u":
@@ -395,14 +592,14 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 			index := m.taskList.Index()
 			t, ok := listItem.(types.Task)
 			if !ok {
-				m.errorMsg = "Something went wrong"
+				m.errorMsg = somethingWentWrongMsg
 				break
 			}
 
 			m.taskInput.SetValue(t.Summary)
 			m.taskInput.Focus()
 			m.taskIndex = index
-			m.taskId = t.ID
+			m.taskID = t.ID
 			m.taskChange = taskUpdateSummary
 			m.activeView = taskEntryView
 			return m, tea.Batch(cmds...)
@@ -412,6 +609,23 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 				break
 			}
 
+			br := false
+			switch m.activeView {
+			case taskListView:
+				if m.taskList.IsFiltered() {
+					br = true
+				}
+
+			case archivedTaskListView:
+				if m.archivedTaskList.IsFiltered() {
+					br = true
+				}
+			}
+
+			if br {
+				break
+			}
+
 			cmds = append(cmds, fetchTasks(m.db, true, pers.TaskNumLimit))
 			cmds = append(cmds, fetchTasks(m.db, false, pers.TaskNumLimit))
 
@@ -422,11 +636,16 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 					break
 				}
 
+				if m.taskList.IsFiltered() {
+					m.errorMsg = "Cannot archive items when the task list is filtered"
+					break
+				}
+
 				listItem := m.taskList.SelectedItem()
 				index := m.taskList.Index()
 				t, ok := listItem.(types.Task)
 				if !ok {
-					m.errorMsg = "Something went wrong"
+					m.errorMsg = "Something went wrong; cannot archive item"
 					break
 				}
 
@@ -438,11 +657,16 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 					break
 				}
 
+				if m.archivedTaskList.IsFiltered() {
+					m.errorMsg = "Cannot unarchive items when the task list is filtered"
+					break
+				}
+
 				listItem := m.archivedTaskList.SelectedItem()
 				index := m.archivedTaskList.Index()
 				t, ok := listItem.(types.Task)
 				if !ok {
-					m.errorMsg = "Something went wrong"
+					m.errorMsg = somethingWentWrongMsg
 					break
 				}
 
@@ -451,39 +675,149 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 			}
 
 		case "ctrl+x":
+			if m.activeView != taskListView && m.activeView != archivedTaskListView {
+				break
+			}
+
+			quit := false
 			switch m.activeView {
 			case taskListView:
 				if len(m.taskList.Items()) == 0 {
+					quit = true
 					break
 				}
 
+				if m.taskList.IsFiltered() {
+					m.errorMsg = cannotDeleteWhenFilteredMsg
+					quit = true
+					break
+				}
+			case archivedTaskListView:
+				if len(m.archivedTaskList.Items()) == 0 {
+					quit = true
+					break
+				}
+
+				if m.archivedTaskList.IsFiltered() {
+					m.errorMsg = cannotDeleteWhenFilteredMsg
+					quit = true
+					break
+				}
+			}
+
+			if quit {
+				break
+			}
+
+			if m.cfg.ConfirmBeforeDeletion && !m.showDeletePrompt {
+				m.showDeletePrompt = true
+
+				switch m.activeView {
+				case taskListView:
+					m.taskList.Title = "delete ?"
+					m.taskList.Styles.Title = m.taskList.Styles.Title.Background(lipgloss.Color(promptColor))
+				case archivedTaskListView:
+					m.archivedTaskList.Title = "delete ?"
+					m.archivedTaskList.Styles.Title = m.archivedTaskList.Styles.Title.Background(lipgloss.Color(promptColor))
+				}
+
+				break
+			}
+
+			switch m.activeView {
+			case taskListView:
 				index := m.taskList.Index()
 				t, ok := m.taskList.SelectedItem().(types.Task)
 				if !ok {
-					m.errorMsg = "Something went wrong"
+					m.errorMsg = somethingWentWrongMsg
 					break
 				}
 				cmd = deleteTask(m.db, t.ID, index, true)
 				cmds = append(cmds, cmd)
-
-			case archivedTaskListView:
-				if len(m.archivedTaskList.Items()) == 0 {
-					break
+				if m.cfg.ConfirmBeforeDeletion {
+					m.showDeletePrompt = false
+					m.taskList.Title = m.cfg.TaskListTitle
+					m.taskList.Styles.Title = m.taskList.Styles.Title.Background(lipgloss.Color(m.cfg.TaskListColor))
 				}
 
+			case archivedTaskListView:
 				index := m.archivedTaskList.Index()
 				task, ok := m.archivedTaskList.SelectedItem().(types.Task)
 				if !ok {
-					m.errorMsg = "Something went wrong"
+					m.errorMsg = somethingWentWrongMsg
 					break
 				}
 
 				cmd = deleteTask(m.db, task.ID, index, false)
 				cmds = append(cmds, cmd)
+				if m.cfg.ConfirmBeforeDeletion {
+					m.showDeletePrompt = false
+					m.archivedTaskList.Title = archivedTitle
+					m.archivedTaskList.Styles.Title = m.archivedTaskList.Styles.Title.Background(lipgloss.Color(m.cfg.ArchivedTaskListColor))
+				}
 			}
 
+		case "ctrl+p":
+			if m.activeView != taskListView && m.activeView != archivedTaskListView {
+				break
+			}
+
+			var taskList list.Model
+			taskPrefixes := make(map[types.TaskPrefix]struct{})
+
+			switch m.activeView {
+			case taskListView:
+				taskList = m.taskList
+			case archivedTaskListView:
+				taskList = m.archivedTaskList
+			}
+
+			if len(taskList.Items()) == 0 {
+				m.errorMsg = "No items in task list"
+				break
+			}
+
+			for _, li := range taskList.Items() {
+				t, ok := li.(types.Task)
+				if ok {
+					prefix, pOk := t.Prefix()
+					if pOk {
+						taskPrefixes[prefix] = struct{}{}
+					}
+				}
+			}
+			var prefixes []types.TaskPrefix
+			for k := range taskPrefixes {
+				prefixes = append(prefixes, k)
+			}
+
+			if len(prefixes) == 0 {
+				m.errorMsg = "No prefixes in task list"
+				break
+			}
+
+			if len(prefixes) == 1 {
+				m.errorMsg = "Only 1 unique prefix in task list"
+				break
+			}
+
+			sort.Slice(prefixes, func(i, j int) bool {
+				return prefixes[i] < prefixes[j]
+			})
+
+			pi := make([]list.Item, len(prefixes))
+			for i, p := range prefixes {
+				pi[i] = list.Item(p)
+			}
+
+			m.prefixSearchList.SetItems(pi)
+			m.lastActiveView = m.activeView
+			m.activeView = prefixSelectionView
+			m.prefixSearchList.Title = "filter by prefix"
+			m.prefixSearchUse = prefixFilter
+
 		case "enter":
-			if m.activeView != taskListView && m.activeView != contextBookmarksView {
+			if m.activeView != taskListView && m.activeView != archivedTaskListView && m.activeView != contextBookmarksView && m.activeView != prefixSelectionView {
 				break
 			}
 			switch m.activeView {
@@ -492,24 +826,157 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 					break
 				}
 
-				if m.taskList.Index() == 0 {
+				if m.taskList.IsFiltered() {
+					selected, ok := m.taskList.SelectedItem().(types.Task)
+					if !ok {
+						m.errorMsg = somethingWentWrongMsg
+						break
+					}
+
+					listIndex, ok := m.tlIndexMap[selected.ID]
+					if !ok {
+						m.errorMsg = somethingWentWrongMsg
+						break
+					}
+
+					m.taskList.ResetFilter()
+					m.taskList.Select(listIndex)
 					break
 				}
 
 				index := m.taskList.Index()
+
+				if index == 0 {
+					m.errorMsg = "This item is already at the top of the list"
+					break
+				}
+
 				listItem := m.taskList.SelectedItem()
 				m.taskList.RemoveItem(index)
 				cmd = m.taskList.InsertItem(0, listItem)
 				cmds = append(cmds, cmd)
 				m.taskList.Select(0)
 
-				cmd = m.updateTaskSequence()
+				cmd = m.updateActiveTasksSequence()
 				cmds = append(cmds, cmd)
+
+			case archivedTaskListView:
+				if len(m.archivedTaskList.Items()) == 0 {
+					break
+				}
+
+				if !m.archivedTaskList.IsFiltered() {
+					break
+				}
+
+				selected, ok := m.archivedTaskList.SelectedItem().(types.Task)
+				if !ok {
+					m.errorMsg = somethingWentWrongMsg
+					break
+				}
+
+				listIndex, ok := m.atlIndexMap[selected.ID]
+				if !ok {
+					m.errorMsg = somethingWentWrongMsg
+					break
+				}
+
+				m.archivedTaskList.ResetFilter()
+				m.archivedTaskList.Select(listIndex)
+
 			case contextBookmarksView:
-				url := m.contextBMList.SelectedItem().FilterValue()
-				cmds = append(cmds, openURL(url))
+				uri := m.taskBMList.SelectedItem().FilterValue()
+				cmds = append(cmds, openURI(uri))
+			case prefixSelectionView:
+				prefix := m.prefixSearchList.SelectedItem().FilterValue()
+
+				switch m.prefixSearchUse {
+				case prefixFilter:
+					var taskList list.Model
+
+					switch m.activeTaskList {
+					case activeTasks:
+						taskList = m.taskList
+					case archivedTasks:
+						taskList = m.archivedTaskList
+					}
+
+					taskList.ResetFilter()
+					var tlCmd tea.Cmd
+
+					runes := []rune(prefix)
+
+					if len(runes) > 1 {
+						taskList.FilterInput.SetValue(string(runes[:len(runes)-1]))
+					}
+
+					taskList, tlCmd = taskList.Update(tea.KeyMsg{Type: -1, Runes: []int32{47}, Alt: false, Paste: false})
+					cmds = append(cmds, tlCmd)
+
+					taskList, tlCmd = taskList.Update(tea.KeyMsg{Type: -1, Runes: []rune{runes[len(runes)-1]}, Alt: false, Paste: false})
+					cmds = append(cmds, tlCmd)
+
+					// TODO: Try sending ENTER programmatically too
+					// taskList, tlCmd = taskList.Update(tea.KeyMsg{Type: 13, Runes: []int32(nil), Alt: false, Paste: false})
+					// or
+					// taskList, tlCmd = taskList.Update(tea.KeyEnter)
+					// this results in the list's paginator being broken, so requires another manual ENTER keypress
+
+					switch m.activeTaskList {
+					case activeTasks:
+						m.taskList = taskList
+						m.activeView = taskListView
+					case archivedTasks:
+						m.archivedTaskList = taskList
+						m.activeView = archivedTaskListView
+					}
+
+					return m, tea.Sequence(cmds...)
+
+				case prefixChoose:
+					m.taskInput.SetValue(getSummaryWithNewPrefix(m.taskInput.Value(), prefix))
+					m.activeView = taskEntryView
+				}
+
 			}
 
+		case "E", "$":
+			if m.activeView != taskListView {
+				break
+			}
+
+			if len(m.taskList.Items()) == 0 {
+				break
+			}
+
+			if m.taskList.IsFiltered() {
+				m.errorMsg = cannotMoveWhenFilteredMsg
+				break
+			}
+
+			index := m.taskList.Index()
+
+			lastIndex := len(m.taskList.Items()) - 1
+
+			if index == lastIndex {
+				m.errorMsg = "This item is already at the end of the list"
+				break
+			}
+
+			if m.taskList.IsFiltered() {
+				m.taskList.ResetFilter()
+				m.taskList.Select(index)
+			}
+
+			listItem := m.taskList.SelectedItem()
+			m.taskList.RemoveItem(index)
+			cmd = m.taskList.InsertItem(lastIndex, listItem)
+			cmds = append(cmds, cmd)
+			m.taskList.Select(lastIndex)
+
+			cmd = m.updateActiveTasksSequence()
+			cmds = append(cmds, cmd)
+
 		case "c":
 			if m.activeView != taskListView && m.activeView != archivedTaskListView && m.activeView != taskDetailsView {
 				break
@@ -523,14 +990,14 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 			case activeTasks:
 				t, ok = m.taskList.SelectedItem().(types.Task)
 				if !ok {
-					m.errorMsg = "Something went wrong"
+					m.errorMsg = somethingWentWrongMsg
 					break
 				}
 				index = m.taskList.Index()
 			case archivedTasks:
 				t, ok = m.archivedTaskList.SelectedItem().(types.Task)
 				if !ok {
-					m.errorMsg = "Something went wrong"
+					m.errorMsg = somethingWentWrongMsg
 					break
 				}
 				index = m.archivedTaskList.Index()
@@ -562,85 +1029,29 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 				break
 			}
 
-			w, h := listStyle.GetFrameSize()
-			var taskList list.Model
-			var archivedTaskList list.Model
-			_, h2 := headerStyle.GetFrameSize()
-			_, h3 := statusBarMsgStyle.GetFrameSize()
-
-			tlIndex := m.taskList.Index()
-			atlIndex := m.archivedTaskList.Index()
-
-			var listHeight int
-			if m.cfg.ShowContext {
-				listHeight = m.terminalHeight/2 - h
-			} else {
-				listHeight = m.terminalHeight - h - 4
-			}
+			var tlDel list.ItemDelegate
+			var atlDel list.ItemDelegate
 
 			switch m.cfg.ListDensity {
 			case Compact:
-				taskList = list.New(m.taskList.Items(),
-					newTaskListDelegate(lipgloss.Color(m.cfg.TaskListColor)),
-					m.terminalWidth-w,
-					listHeight,
-				)
-				taskList.SetShowStatusBar(true)
-
-				archivedTaskList = list.New(m.archivedTaskList.Items(),
-					newTaskListDelegate(lipgloss.Color(m.cfg.ArchivedTaskListColor)),
-					m.terminalWidth-w,
-					listHeight,
-				)
-				archivedTaskList.SetShowStatusBar(true)
+				tlDel = newSpaciousListDelegate(lipgloss.Color(m.cfg.TaskListColor), true, 1)
+				atlDel = newSpaciousListDelegate(lipgloss.Color(m.cfg.ArchivedTaskListColor), true, 1)
 
 				m.cfg.ListDensity = Spacious
 
 			case Spacious:
-				taskList = list.New(m.taskList.Items(),
-					itemDelegate{selStyle: m.tlSelStyle},
-					m.terminalWidth-w,
-					compactListHeight,
-				)
-				taskList.SetShowStatusBar(false)
-
-				archivedTaskList = list.New(m.archivedTaskList.Items(),
-					itemDelegate{selStyle: m.tlSelStyle},
-					m.terminalWidth-w,
-					compactListHeight,
-				)
+				tlDel = compactItemDelegate{m.tlSelStyle}
+				atlDel = compactItemDelegate{m.atlSelStyle}
 				m.cfg.ListDensity = Compact
-				archivedTaskList.SetShowStatusBar(false)
 			}
 
-			taskList.SetShowTitle(false)
-			taskList.SetFilteringEnabled(false)
-			taskList.SetShowHelp(false)
-			taskList.DisableQuitKeybindings()
-			taskList.Styles.Title = m.taskList.Styles.Title
-			taskList.KeyMap.PrevPage.SetKeys("left", "h", "pgup")
-			taskList.KeyMap.NextPage.SetKeys("right", "l", "pgdown")
+			m.taskList.SetDelegate(tlDel)
+			m.archivedTaskList.SetDelegate(atlDel)
 
-			m.taskList = taskList
-			m.taskList.Select(tlIndex)
-
-			archivedTaskList.SetShowTitle(false)
-			archivedTaskList.SetFilteringEnabled(false)
-			archivedTaskList.SetShowHelp(false)
-			archivedTaskList.DisableQuitKeybindings()
-			archivedTaskList.KeyMap.PrevPage.SetKeys("left", "h", "pgup")
-			archivedTaskList.KeyMap.NextPage.SetKeys("right", "l", "pgdown")
-
-			m.archivedTaskList = archivedTaskList
-			m.archivedTaskList.Select(atlIndex)
-
-			var contextHeight int
-			if m.cfg.ListDensity == Compact {
-				contextHeight = m.terminalHeight - m.taskList.Height() - h2 - h3 - 6
-			} else {
-				contextHeight = m.terminalHeight - m.taskList.Height() - h2 - h3 - 5
+			if m.cfg.ShowContext {
+				m.taskList.SetHeight(m.shortenedListHt)
+				m.archivedTaskList.SetHeight(m.shortenedListHt)
 			}
-			m.contextVP.Height = contextHeight
 
 		case "C":
 			if m.activeView != taskListView && m.activeView != archivedTaskListView {
@@ -650,28 +1061,24 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 			m.cfg.ShowContext = !m.cfg.ShowContext
 
 			_, h := listStyle.GetFrameSize()
-			var listHeight int
-			if m.cfg.ListDensity == Spacious {
-				switch m.cfg.ShowContext {
-				case true:
-					listHeight = m.terminalHeight/2 - h
-				case false:
-					listHeight = m.terminalHeight - h - 4
-				}
-				m.taskList.SetHeight(listHeight)
-				m.archivedTaskList.SetHeight(listHeight)
-			}
-
-			_, h2 := headerStyle.GetFrameSize()
 			_, h3 := statusBarMsgStyle.GetFrameSize()
+			var listHeight int
 
-			var contextHeight int
-			if m.cfg.ListDensity == Compact {
-				contextHeight = m.terminalHeight - m.taskList.Height() - h2 - h3 - 6
+			if m.cfg.ShowContext {
+				listHeight = m.shortenedListHt
 			} else {
-				contextHeight = m.terminalHeight - m.taskList.Height() - h2 - h3 - 5
+				listHeight = m.terminalHeight - h - h3 - 1
 			}
-			m.contextVP.Height = contextHeight
+
+			if m.cfg.ListDensity == Compact {
+				tlDel := compactItemDelegate{m.tlSelStyle}
+				atlDel := compactItemDelegate{m.atlSelStyle}
+				m.taskList.SetDelegate(tlDel)
+				m.archivedTaskList.SetDelegate(atlDel)
+			}
+
+			m.taskList.SetHeight(listHeight)
+			m.archivedTaskList.SetHeight(listHeight)
 
 		case "d":
 			if m.activeView == taskDetailsView {
@@ -760,26 +1167,26 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 				break
 			}
 
-			urls, ok := m.getTaskUrls()
+			uris, ok := m.getTaskURIs()
 			if !ok {
 				break
 			}
 
-			if len(urls) == 0 {
+			if len(uris) == 0 {
 				m.errorMsg = "No bookmarks for this task"
 				break
 			}
 
-			if len(urls) == 1 {
-				cmds = append(cmds, openURL(urls[0]))
+			if len(uris) == 1 {
+				cmds = append(cmds, openURI(uris[0]))
 				break
 			}
 
-			bmItems := make([]list.Item, len(urls))
-			for i, url := range urls {
-				bmItems[i] = list.Item(types.ContextBookmark(url))
+			bmItems := make([]list.Item, len(uris))
+			for i, uri := range uris {
+				bmItems[i] = list.Item(types.ContextBookmark(uri))
 			}
-			m.contextBMList.SetItems(bmItems)
+			m.taskBMList.SetItems(bmItems)
 			switch m.activeView {
 			case taskListView:
 				m.activeTaskList = activeTasks
@@ -794,28 +1201,28 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 				break
 			}
 
-			urls, ok := m.getTaskUrls()
+			uris, ok := m.getTaskURIs()
 			if !ok {
 				break
 			}
 
-			if len(urls) == 0 {
+			if len(uris) == 0 {
 				m.errorMsg = "No bookmarks for this task"
 				break
 			}
 
-			if len(urls) == 1 {
-				cmds = append(cmds, openURL(urls[0]))
+			if len(uris) == 1 {
+				cmds = append(cmds, openURI(uris[0]))
 				break
 			}
 
 			if m.rtos == types.GOOSDarwin {
-				cmds = append(cmds, openURLsDarwin(urls))
+				cmds = append(cmds, openURIsDarwin(uris))
 				break
 			}
 
-			for _, url := range urls {
-				cmds = append(cmds, openURL(url))
+			for _, uri := range uris {
+				cmds = append(cmds, openURI(uri))
 			}
 
 		case "y":
@@ -861,18 +1268,19 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 			break
 		}
 
-		entry := list.Item(types.Task{
+		t := types.Task{
 			ID:        msg.id,
 			Summary:   msg.taskSummary,
 			Active:    true,
 			CreatedAt: msg.createdAt,
 			UpdatedAt: msg.updatedAt,
-		})
+		}
+		entry := list.Item(t)
 		cmd = m.taskList.InsertItem(m.taskIndex, entry)
 		cmds = append(cmds, cmd)
 		m.taskList.Select(m.taskIndex)
 
-		cmd = m.updateTaskSequence()
+		cmd = m.updateActiveTasksSequence()
 		cmds = append(cmds, cmd)
 
 	case taskDeletedMsg:
@@ -884,10 +1292,11 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 		switch msg.active {
 		case true:
 			m.taskList.RemoveItem(msg.listIndex)
-			cmd = m.updateTaskSequence()
+			cmd = m.updateActiveTasksSequence()
 			cmds = append(cmds, cmd)
 		case false:
 			m.archivedTaskList.RemoveItem(msg.listIndex)
+			m.updateArchivedTasksIndex()
 		}
 
 	case taskSequenceUpdatedMsg:
@@ -956,7 +1365,7 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 				m.setContextFSContent(t)
 			}
 			// to force refresh
-			m.contextVPTaskId = 0
+			m.contextVPTaskID = 0
 		}
 
 	case taskStatusChangedMsg:
@@ -988,7 +1397,8 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 				m.archivedTaskList.InsertItem(0, list.Item(t))
 				m.taskList.RemoveItem(msg.listIndex)
 			}
-			cmd = m.updateTaskSequence()
+			cmd = m.updateActiveTasksSequence()
+			m.updateArchivedTasksIndex()
 			cmds = append(cmds, cmd)
 		}
 
@@ -1004,17 +1414,30 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 					taskItems[i] = t
 				}
 				m.taskList.SetItems(taskItems)
+				m.taskList.Select(0)
+
+				tlIndexMap := make(map[uint64]int)
+				for i, ti := range m.taskList.Items() {
+					t, ok := ti.(types.Task)
+					if ok {
+						tlIndexMap[t.ID] = i
+					}
+				}
+				m.tlIndexMap = tlIndexMap
+
 			case false:
 				archivedTaskItems := make([]list.Item, len(msg.tasks))
 				for i, t := range msg.tasks {
 					archivedTaskItems[i] = t
 				}
 				m.archivedTaskList.SetItems(archivedTaskItems)
+				m.archivedTaskList.Select(0)
+				m.updateArchivedTasksIndex()
 			}
 		}
 	case textEditorClosed:
 		if msg.err != nil {
-			m.errorMsg = fmt.Sprintf("Something went wrong: %s", msg.err)
+			m.errorMsg = fmt.Sprintf("%s: %s", somethingWentWrongMsg, msg.err)
 			_ = os.Remove(msg.fPath)
 			break
 		}
@@ -1039,14 +1462,14 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 			break
 		}
 
-		cmds = append(cmds, updateTaskContext(m.db, msg.taskIndex, msg.taskId, string(context), m.activeTaskList))
-	case urlOpenedMsg:
+		cmds = append(cmds, updateTaskContext(m.db, msg.taskIndex, msg.taskID, string(context), m.activeTaskList))
+	case uriOpenedMsg:
 		if msg.err != nil {
-			m.errorMsg = fmt.Sprintf("Error opening url: %s", msg.err)
+			m.errorMsg = fmt.Sprintf("Error opening uri: %s", msg.err)
 		}
-	case urlsOpenedDarwinMsg:
+	case urisOpenedDarwinMsg:
 		if msg.err != nil {
-			m.errorMsg = fmt.Sprintf("Error opening urls: %s", msg.err)
+			m.errorMsg = fmt.Sprintf("Error opening uris: %s", msg.err)
 		}
 
 	case contextWrittenToCBMsg:
@@ -1057,23 +1480,12 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 		}
 	}
 
-	if m.cfg.ListDensity == Compact {
-		if len(m.taskList.Items()) > 9 {
-			m.taskList.SetHeight(compactListHeight + 1)
-		} else {
-			m.taskList.SetHeight(compactListHeight)
-		}
-		if len(m.archivedTaskList.Items()) > 9 {
-			m.archivedTaskList.SetHeight(compactListHeight + 1)
-		} else {
-			m.archivedTaskList.SetHeight(compactListHeight)
-		}
-	}
-
 	var viewUpdateCmd tea.Cmd
 	switch m.activeView {
 	case taskListView:
-		m.taskList, viewUpdateCmd = m.taskList.Update(msg)
+		if !skipListUpdate {
+			m.taskList, viewUpdateCmd = m.taskList.Update(msg)
+		}
 
 		if !m.cfg.ShowContext {
 			break
@@ -1084,19 +1496,35 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 			break
 		}
 
-		if m.contextVPTaskId == t.ID {
+		if m.contextVPTaskID == t.ID {
 			break
 		}
 
-		if t.Context != nil {
-			m.contextVP.SetContent(*t.Context)
-		} else {
-			m.contextVP.SetContent(noContextMsg)
+		var detailsToRender string
+		switch t.Context {
+		case nil:
+			detailsToRender = noContextMsg
+		default:
+			detailsToRender = *t.Context
+			switch m.contextMdRenderer {
+			case nil:
+				break
+			default:
+				contextGl, err := m.contextMdRenderer.Render(*t.Context)
+				if err != nil {
+					break
+				}
+				detailsToRender = contextGl
+			}
 		}
-		m.contextVPTaskId = t.ID
+
+		m.contextVP.SetContent(detailsToRender)
+		m.contextVPTaskID = t.ID
 
 	case archivedTaskListView:
-		m.archivedTaskList, viewUpdateCmd = m.archivedTaskList.Update(msg)
+		if !skipListUpdate {
+			m.archivedTaskList, viewUpdateCmd = m.archivedTaskList.Update(msg)
+		}
 
 		if !m.cfg.ShowContext {
 			break
@@ -1107,16 +1535,25 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 			break
 		}
 
-		if m.contextVPTaskId == t.ID {
+		if m.contextVPTaskID == t.ID {
 			break
 		}
 
 		if t.Context != nil {
-			m.contextVP.SetContent(*t.Context)
+			if m.contextMdRenderer != nil {
+				contextGl, err := m.contextMdRenderer.Render(*t.Context)
+				if err != nil {
+					m.contextVP.SetContent(*t.Context)
+				} else {
+					m.contextVP.SetContent(contextGl)
+				}
+			} else {
+				m.contextVP.SetContent(*t.Context)
+			}
 		} else {
 			m.contextVP.SetContent(noContextMsg)
 		}
-		m.contextVPTaskId = t.ID
+		m.contextVPTaskID = t.ID
 
 	case taskEntryView:
 		m.taskInput, viewUpdateCmd = m.taskInput.Update(msg)
@@ -1125,7 +1562,14 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 		m.taskDetailsVP, viewUpdateCmd = m.taskDetailsVP.Update(msg)
 
 	case contextBookmarksView:
-		m.contextBMList, viewUpdateCmd = m.contextBMList.Update(msg)
+		if !skipListUpdate {
+			m.taskBMList, viewUpdateCmd = m.taskBMList.Update(msg)
+		}
+
+	case prefixSelectionView:
+		if !skipListUpdate {
+			m.prefixSearchList, viewUpdateCmd = m.prefixSearchList.Update(msg)
+		}
 
 	case helpView:
 		m.helpVP, viewUpdateCmd = m.helpVP.Update(msg)
@@ -1136,38 +1580,66 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 	return m, tea.Batch(cmds...)
 }
 
-func (m model) updateTaskSequence() tea.Cmd {
+func (m *Model) updateActiveTasksSequence() tea.Cmd {
 	sequence := make([]uint64, len(m.taskList.Items()))
+	tlIndexMap := make(map[uint64]int)
+
 	for i, ti := range m.taskList.Items() {
 		t, ok := ti.(types.Task)
 		if ok {
 			sequence[i] = t.ID
+			tlIndexMap[t.ID] = i
 		}
 	}
 
+	m.tlIndexMap = tlIndexMap
+
 	return updateTaskSequence(m.db, sequence)
 }
 
-func (m model) isSpaceAvailable() bool {
+func (m *Model) updateArchivedTasksIndex() {
+	sequence := make([]uint64, len(m.archivedTaskList.Items()))
+	tlIndexMap := make(map[uint64]int)
+
+	for i, ti := range m.archivedTaskList.Items() {
+		t, ok := ti.(types.Task)
+		if ok {
+			sequence[i] = t.ID
+			tlIndexMap[t.ID] = i
+		}
+	}
+
+	m.atlIndexMap = tlIndexMap
+}
+
+func (m Model) isSpaceAvailable() bool {
 	return len(m.taskList.Items()) < pers.TaskNumLimit
 }
 
-func (m *model) setContextFSContent(task types.Task) {
+func (m *Model) setContextFSContent(task types.Task) {
 	var ctx string
 	if task.Context != nil {
-		ctx = fmt.Sprintf("\n===\n\n%s", *task.Context)
+		ctx = fmt.Sprintf("---\n%s", *task.Context)
 	}
 
-	details := fmt.Sprintf(`summary               %s
-created at            %s
-last updated at       %s
+	details := fmt.Sprintf(`- summary          :    %s
+- created at       :    %s
+- last updated at  :    %s
+
 %s
 `, task.Summary, task.CreatedAt.Format(timeFormat), task.UpdatedAt.Format(timeFormat), ctx)
 
+	if m.taskDetailsMdRenderer != nil {
+		detailsGl, err := m.taskDetailsMdRenderer.Render(details)
+		if err == nil {
+			m.taskDetailsVP.SetContent(detailsGl)
+			return
+		}
+	}
 	m.taskDetailsVP.SetContent(details)
 }
 
-func (m model) getTaskUrls() ([]string, bool) {
+func (m Model) getTaskURIs() ([]string, bool) {
 	var t types.Task
 	var ok bool
 
@@ -1188,11 +1660,11 @@ func (m model) getTaskUrls() ([]string, bool) {
 		return nil, false
 	}
 
-	var urls []string
-	urls = append(urls, utils.ExtractURLs(m.urlRegex, t.Summary)...)
+	var uris []string
+	uris = append(uris, utils.ExtractURIs(m.uriRegex, t.Summary)...)
 	if t.Context != nil {
-		urls = append(urls, utils.ExtractURLs(m.urlRegex, *t.Context)...)
+		uris = append(uris, utils.ExtractURIs(m.uriRegex, *t.Context)...)
 	}
 
-	return urls, true
+	return uris, true
 }
