@@ -3,7 +3,6 @@ package utils
 import (
 	"fmt"
 	"math"
-	"regexp"
 	"strings"
 	"time"
 )
@@ -47,7 +46,3 @@ func HumanizeDuration(durationInSecs int) string {
 
 	return fmt.Sprintf("%dh %dm", int(duration.Hours()), modMins)
 }
-
-func ExtractURLs(rg *regexp.Regexp, text string) []string {
-	return rg.FindAllString(text, -1)
-}
